@@ -1,9 +1,8 @@
-module PostgresqlTypes.Multirange.QuickCheckGen
-where
+module PostgresqlTypes.Multirange.QuickCheckGen where
 
+import qualified Data.Set as Set
 import PostgresqlTypes.Prelude
 import Test.QuickCheck
-import qualified Data.Set as Set
 
 -- | Attention. This generator may run indefinitely if the 'elementGen' has too small variety of possible values.
 setOfSize :: (Ord a) => Int -> Gen a -> Gen (Set.Set a)
@@ -13,4 +12,4 @@ setOfSize n elementGen = go Set.empty 0
       | size >= n = pure currentSet
       | otherwise = do
           newElement <- suchThat elementGen \element -> Set.notMember element currentSet
-          go (Set.insert newElement currentSet) (succ size)
\ No newline at end of file
+          go (Set.insert newElement currentSet) (succ size)
